==> estateplat-common-1.2.3-20180322.092512-51-sources.jar: cn/gtmap/estateplat/model/server/core/GdDy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 过度数据对应抵押信息
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_dy")
public class GdDy implements Serializable {
    @Id
    private String dyid;
    private Date dyksrq;
    private Date dyjsrq;
    private String dyfs;
    private String zjgczl;
    private String zjgcdyfw;
    private String zgzqqdss;
    private String bdclx;
    private String proid;
    private String dydjzmh;
    private Integer isjy;
    private String dbfw;
    private Double bdbzzqse;
    private Double zgzqqdse;
    private Date gxrq;
    private String djlx;
    private String fj;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private Date lzrq;//领证日期
    private Date  zxrq;//修改日期
    private String zxr;//修改人
    private Double pgjg;//评估价格
    private Double bdcjg;//不动产价格
    private Double dymj;//抵押面积
    private String dkfs;//贷款方式
    private String dyhtbh;//抵押合同编号
    private String zwr;//债务人
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String sfgtdb;//是否共同担保
    private Double sydyje;//剩余抵押金额
    private Double sydymj;//剩余抵押面积
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押原因
    private String zxdbr;//注销登簿人
    private Date   zxdbsj;//注销登记时间
    private Integer dysx;//抵押顺序
    private String zxdaywh;//注销档案业务
    public String getSfgtdb() {
        return sfgtdb;
    }

    public void setSfgtdb(String sfgtdb) {
        this.sfgtdb = sfgtdb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getZxrq() {
        return zxrq;
    }

    public void setZxrq(Date zxrq) {
        this.zxrq = zxrq;
    }

    public String getZxr() {
        return zxr;
    }

    public void setZxr(String zxr) {
        this.zxr = zxr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getDyid() {
        return dyid;
    }

    public void setDyid(String dyid) {
        this.dyid = dyid;
    }

    public Date getDyksrq() {
        return dyksrq;
    }

    public void setDyksrq(Date dyksrq) {
        this.dyksrq = dyksrq;
    }

    public Date getDyjsrq() {
        return dyjsrq;
    }

    public void setDyjsrq(Date dyjsrq) {
        this.dyjsrq = dyjsrq;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }


    public String getDydjzmh() {
        return dydjzmh;
    }

    public void setDydjzmh(String dydjzmh) {
        this.dydjzmh = dydjzmh;
    }

    public Integer getIsjy() {
        return isjy;
    }

    public void setIsjy(Integer isjy) {
        this.isjy = isjy;
    }



    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Double getPgjg() {
        return pgjg;
    }

    public void setPgjg(Double pgjg) {
        this.pgjg = pgjg;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getBdcjg() {
        return bdcjg;
    }

    public void setBdcjg(Double bdcjg) {
        this.bdcjg = bdcjg;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Double getSydyje() {
        return sydyje;
    }

    public void setSydyje(Double sydyje) {
        this.sydyje = sydyje;
    }

    public Double getSydymj() {
        return sydymj;
    }

    public void setSydymj(Double sydymj) {
        this.sydymj = sydymj;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Integer getDysx(){
        return dysx;
    }

    public void setDysx(Integer dysx){
        this.dysx = dysx;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }
}

==> estateplat-common-1.2.3-20180329.031826-53-sources.jar: cn/gtmap/estateplat/model/server/core/GdDy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 过度数据对应抵押信息
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_dy")
public class GdDy implements Serializable {
    @Id
    private String dyid;
    private Date dyksrq;
    private Date dyjsrq;
    private String dyfs;
    private String zjgczl;
    private String zjgcdyfw;
    private String zgzqqdss;
    private String bdclx;
    private String proid;
    private String dydjzmh;
    private Integer isjy;
    private String dbfw;
    private Double bdbzzqse;
    private Double zgzqqdse;
    private Date gxrq;
    private String djlx;
    private String fj;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private Date lzrq;//领证日期
    private Date  zxrq;//修改日期
    private String zxr;//修改人
    private Double pgjg;//评估价格
    private Double bdcjg;//不动产价格
    private Double dymj;//抵押面积
    private String dkfs;//贷款方式
    private String dyhtbh;//抵押合同编号
    private String zwr;//债务人
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String sfgtdb;//是否共同担保
    private Double sydyje;//剩余抵押金额
    private Double sydymj;//剩余抵押面积
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押原因
    private String zxdbr;//注销登簿人
    private Date   zxdbsj;//注销登记时间
    private Integer dysx;//抵押顺序
    private String daywh;//档案业务号
    private String zxdaywh;//注销档案业务号

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getSfgtdb() {
        return sfgtdb;
    }

    public void setSfgtdb(String sfgtdb) {
        this.sfgtdb = sfgtdb;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Date getZxrq() {
        return zxrq;
    }

    public void setZxrq(Date zxrq) {
        this.zxrq = zxrq;
    }

    public String getZxr() {
        return zxr;
    }

    public void setZxr(String zxr) {
        this.zxr = zxr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getDyid() {
        return dyid;
    }

    public void setDyid(String dyid) {
        this.dyid = dyid;
    }

    public Date getDyksrq() {
        return dyksrq;
    }

    public void setDyksrq(Date dyksrq) {
        this.dyksrq = dyksrq;
    }

    public Date getDyjsrq() {
        return dyjsrq;
    }

    public void setDyjsrq(Date dyjsrq) {
        this.dyjsrq = dyjsrq;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }


    public String getDydjzmh() {
        return dydjzmh;
    }

    public void setDydjzmh(String dydjzmh) {
        this.dydjzmh = dydjzmh;
    }

    public Integer getIsjy() {
        return isjy;
    }

    public void setIsjy(Integer isjy) {
        this.isjy = isjy;
    }



    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Double getPgjg() {
        return pgjg;
    }

    public void setPgjg(Double pgjg) {
        this.pgjg = pgjg;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getBdcjg() {
        return bdcjg;
    }

    public void setBdcjg(Double bdcjg) {
        this.bdcjg = bdcjg;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Double getSydyje() {
        return sydyje;
    }

    public void setSydyje(Double sydyje) {
        this.sydyje = sydyje;
    }

    public Double getSydymj() {
        return sydymj;
    }

    public void setSydymj(Double sydymj) {
        this.sydymj = sydymj;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Integer getDysx(){
        return dysx;
    }

    public void setDysx(Integer dysx){
        this.dysx = dysx;
    }
}
